==> fzm-joying-dev_1.2.0.tar.gz: fzm-joying-dev_1.2.0/joying-common/src/main/java/com/fzm/common/entity/CopyrightApply.java <==
package com.fzm.common.entity;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fzm.common.entity.dto.CopyrightDTO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.Date;

@Data
@NoArgsConstructor
@TableName("tb_copyright_apply")
@ApiModel(value = "版权申请")
public class CopyrightApply {

    @TableId(type = IdType.AUTO)
    @ApiModelProperty(value = "主键")
    private Integer id;

    @ApiModelProperty(value = "流水号")
    private String serialNum;

    @ApiModelProperty(value = "用户id")
    private Integer userId;

    @ApiModelProperty(value = "nft哈希")
    private String nftHash;

    @ApiModelProperty(value = "nft名称")
    private String nftName;

    @ApiModelProperty(value = "登记委托书")
    private String registerEntrust;

    @ApiModelProperty(value = "作品名称")
    private String opusName;

    @ApiModelProperty(value = "作品类别id")
    private Integer opusCategoryId;

    @ApiModelProperty(value = "作品性质")
    private String opusProperty;

    @ApiModelProperty(value = "内容简介")
    private String contentSynopsis;

    @ApiModelProperty(value = "创作过程")
    private String createProcess;

    @ApiModelProperty(value = "作品完成日期")
    private Date opusCompleteDate;

    @ApiModelProperty(value = "作品完成省份")
    private String opusCompleteProvince;

    @ApiModelProperty(value = "作品完成城市")
    private String opusCompleteCity;

    @ApiModelProperty(value = "'发表状态  0-未发表  1-已发表")
    private Integer publishState;

    @ApiModelProperty(value = "首次发表日期")
    private Date firstPublishDate;

    @ApiModelProperty(value = "首次发表省份")
    private String firstPublishProvince;

    @ApiModelProperty(value = "首次发表城市")
    private String firstPublishCity;

    @ApiModelProperty(value = "权力取得方式")
    private String authorityAcquireMode;

    @ApiModelProperty(value = "权力取得证明材料的文件地址")
    private String authorityAcquireProve;

    @ApiModelProperty(value = "权力归属方式")
    private String authorityAscriptionMode;

    @ApiModelProperty(value = "权力归属证明材料的文件地址")
    private String authorityAscriptionProve;

    @ApiModelProperty(value = "作品权力保证书")
    private String opusPowerGuarantee;

    @ApiModelProperty(value = "申请时间")
    private Date applyTime;

    @ApiModelProperty(value = "版权申请后台核验通过时间")
    private Date passTime;

    // 参考枚举类-com.fzm.common.enums.CopyrightApplyState
    @ApiModelProperty(value = "登记状态  -2:待支付 -1:已撤回 0:待核验  2:提交审核 3:已驳回 4:审核成功 5:驳回 6:待审核 7:待终审")
    private Integer registerState;

    @ApiModelProperty(value = "存证哈希")
    private String evidenceHash;

    @ApiModelProperty(value = "存证日期")
    private Date evidenceDate;

    @ApiModelProperty(value = "驳回理由")
    private String rejectReason;

    @JsonProperty(access = JsonProperty.Access.WRITE_ONLY)
    @ApiModelProperty("json串")
    private String content;

    @ApiModelProperty("登记证书编号,在版权登记审核通过后生成")
    private String registerCode;

    private Date createDate;

    private Date updateDate;

    public CopyrightApply(CopyrightDTO copyrightDTO) {
        BeanUtil.copyProperties(copyrightDTO, this, true);
    }

}

==> fzm-joying-dev_1.3.0.tar.gz: fzm-joying-dev_1.3.0/joying-common/src/main/java/com/fzm/common/entity/CopyrightApply.java <==
package com.fzm.common.entity;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fzm.common.entity.dto.CopyrightDTO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.Date;

@Data
@NoArgsConstructor
@TableName("tb_copyright_apply")
@ApiModel(value = "版权申请")
public class CopyrightApply {

    @TableId(type = IdType.AUTO)
    @ApiModelProperty(value = "主键")
    private Integer id;

    @ApiModelProperty(value = "流水号")
    private String serialNum;

    @ApiModelProperty(value = "用户id")
    private Integer userId;

    @ApiModelProperty(value = "nft哈希")
    private String nftHash;

    @ApiModelProperty(value = "nft名称")
    private String nftName;

    @ApiModelProperty(value = "登记委托书")
    private String registerEntrust;

    @ApiModelProperty(value = "作品名称")
    private String opusName;

    @ApiModelProperty(value = "作品类别id")
    private Integer opusCategoryId;

    @ApiModelProperty(value = "作品性质")
    private String opusProperty;

    @ApiModelProperty(value = "内容简介")
    private String contentSynopsis;

    @ApiModelProperty(value = "创作过程")
    private String createProcess;

    @ApiModelProperty(value = "作品完成日期")
    private Date opusCompleteDate;

    @ApiModelProperty(value = "作品完成省份")
    private String opusCompleteProvince;

    @ApiModelProperty(value = "作品完成城市")
    private String opusCompleteCity;

    @ApiModelProperty(value = "'发表状态  0-未发表  1-已发表")
    private Integer publishState;

    @ApiModelProperty(value = "首次发表日期")
    private Date firstPublishDate;

    @ApiModelProperty(value = "首次发表省份")
    private String firstPublishProvince;

    @ApiModelProperty(value = "首次发表城市")
    private String firstPublishCity;

    @ApiModelProperty(value = "权力取得方式")
    private String authorityAcquireMode;

    @ApiModelProperty(value = "权力取得证明材料的文件地址")
    private String authorityAcquireProve;

    @ApiModelProperty(value = "权力归属方式")
    private String authorityAscriptionMode;

    @ApiModelProperty(value = "权力归属证明材料的文件地址")
    private String authorityAscriptionProve;

    @ApiModelProperty(value = "作品权力保证书")
    private String opusPowerGuarantee;

    @ApiModelProperty(value = "申请时间")
    private Date applyTime;

    @ApiModelProperty(value = "版权申请后台核验通过时间")
    private Date passTime;

    @ApiModelProperty(value = "登记状态  0-待审核  1-登记成功 2-审核失败")
    private Integer registerState;

    @ApiModelProperty(value = "存证哈希")
    private String evidenceHash;

    @ApiModelProperty(value = "存证日期")
    private Date evidenceDate;

    @ApiModelProperty(value = "驳回理由")
    private String rejectReason;

    @JsonProperty(access = JsonProperty.Access.WRITE_ONLY)
    @ApiModelProperty("json串")
    private String content;

    @ApiModelProperty("登记证书编号,在版权登记审核通过后生成")
    private String registerCode;

    private Date createDate;

    private Date updateDate;

    public CopyrightApply(CopyrightDTO copyrightDTO) {
        BeanUtil.copyProperties(copyrightDTO, this, true);
    }

}
